pub struct Pid32(pub i32);Expand description
Process or thread id (32-bit)
Tuple Fields
0: i32Trait Implementations
Sourceimpl FromBytes<'_> for Pid32
impl FromBytes<'_> for Pid32
Sourcefn from_bytes(buf: &mut &[u8]) -> Result<Self, FromBytesError>where
Self: Sized,
fn from_bytes(buf: &mut &[u8]) -> Result<Self, FromBytesError>where
Self: Sized,
Read the binary representation of a field and return the parsed representation Read more
Sourcefn from_maybe_bytes(buf: Option<&mut &'a [u8]>) -> Result<Self, FromBytesError>
fn from_maybe_bytes(buf: Option<&mut &'a [u8]>) -> Result<Self, FromBytesError>
Read the binary representation of a field from a buffer that may or may not exist Read more
Sourceimpl Ord for Pid32
impl Ord for Pid32
Sourceimpl PartialOrd for Pid32
impl PartialOrd for Pid32
impl Copy for Pid32
impl Eq for Pid32
impl StructuralPartialEq for Pid32