pub struct SyscallResult(pub i64);Expand description
Syscall result
Tuple Fields
0: i64Trait Implementations
Sourceimpl Clone for SyscallResult
impl Clone for SyscallResult
Sourcefn clone(&self) -> SyscallResult
fn clone(&self) -> SyscallResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SyscallResult
Sourceimpl Debug for SyscallResult
impl Debug for SyscallResult
Sourceimpl Default for SyscallResult
impl Default for SyscallResult
Sourcefn default() -> SyscallResult
fn default() -> SyscallResult
Returns the “default value” for a type. Read more
impl Eq for SyscallResult
Sourceimpl FromBytes<'_> for SyscallResult
impl FromBytes<'_> for SyscallResult
Sourcefn from_bytes(buf: &mut &[u8]) -> Result<Self, FromBytesError>where
Self: Sized,
fn from_bytes(buf: &mut &[u8]) -> Result<Self, FromBytesError>where
Self: Sized,
Read the binary representation of a field and return the parsed representation Read more
Sourcefn from_maybe_bytes(buf: Option<&mut &'a [u8]>) -> Result<Self, FromBytesError>
fn from_maybe_bytes(buf: Option<&mut &'a [u8]>) -> Result<Self, FromBytesError>
Read the binary representation of a field from a buffer that may or may not exist Read more
Sourceimpl Hash for SyscallResult
impl Hash for SyscallResult
Sourceimpl LowerHex for SyscallResult
impl LowerHex for SyscallResult
Sourceimpl Ord for SyscallResult
impl Ord for SyscallResult
Sourcefn cmp(&self, other: &SyscallResult) -> Ordering
fn cmp(&self, other: &SyscallResult) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SyscallResult
impl PartialEq for SyscallResult
Sourcefn eq(&self, other: &SyscallResult) -> bool
fn eq(&self, other: &SyscallResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SyscallResult
impl PartialOrd for SyscallResult
impl StructuralPartialEq for SyscallResult
Sourceimpl ToBytes for SyscallResult
impl ToBytes for SyscallResult